<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Terug naar de volledig grafische interface',
	'access_mode_texte' => 'Vereenvoudigde tekstinterface weergeven',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Artikel wijzigen',
	'admin_modifier_auteur' => 'Auteur wijzigen',
	'admin_modifier_breve' => 'Nieuwsflits wijzigen',
	'admin_modifier_mot' => 'Trefwoord wijzigen',
	'admin_modifier_rubrique' => 'Rubriek wijzigen',
	'admin_recalculer' => 'Pagina vernieuwen',
	'afficher_calendrier' => 'Toon kalender',
	'afficher_trad' => 'vertalingen weergeven',
	'alerte_maj_impossible' => '<b>Let op!</b> Het updaten van de SQL-database naar versie @version@ is niet mogelijk. Misschien wegens een probleem van wijzigingsrecht op de database. Neem contact op met je provider.',
	'alerte_modif_info_concourante' => 'OPGELET! Deze informatie werd elders gewijzigd. De huidige waarde is:',
	'analyse_xml' => 'XML Analyse',
	'annuler' => 'Annuleren',
	'antispam_champ_vide' => 'Gelieve dit veld leeg te laten:',
	'articles_recents' => 'Meest recente artikelen',
	'avis_1_erreur_saisie' => 'Er zit één fout in de ingevoerde gegevens, controleren a.u.b.',
	'avis_archive_incorrect' => 'het bewaarde bestand is geen SPIP-bestand',
	'avis_archive_invalide' => 'het bewaarde bestand is niet bruikbaar',
	'avis_attention' => 'OPGELET!',
	'avis_champ_incorrect_type_objet' => 'Veldnaam @name@ is onjuist voor een object van het type @type@',
	'avis_colonne_inexistante' => 'De kolom @col@ bestaat niet',
	'avis_erreur' => 'Fout: zie hieronder',
	'avis_erreur_connexion' => 'Verbinding mislukt',
	'avis_erreur_cookie' => 'Probleem met cookie',
	'avis_erreur_fonction_contexte' => 'Programmafout. Deze functie kan niet worden opgeroepen in deze context.',
	'avis_erreur_mysql' => 'SQL fout',
	'avis_erreur_sauvegarde' => 'Backup fout (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Probleem met toegang tot het privé gedeelte.',
	'avis_nb_erreurs_saisie' => 'Er zitten @nb@  fouten in de ingevoerde gegevens, controleren a.u.b.',

	// B
	'barre_a_accent_grave' => 'Hoofdletter A met accent grave toevoegen',
	'barre_aide' => 'Gebruik de typografische snelkoppelingen voor de pagina-opmaak',
	'barre_e_accent_aigu' => 'Hoofdletter E met accent aigu toevoegen',
	'barre_eo' => 'O gekoppeld aan E (ligatuur) toevoegen',
	'barre_eo_maj' => 'Hoofdletter O gekoppeld aan E (ligatuur) toevoegen',
	'barre_euro' => '€ teken invoegen',
	'barre_gras' => 'In het {{vet}} zetten',
	'barre_guillemets' => 'Van « haakjes » voorzien',
	'barre_guillemets_simples' => 'Van „haakjes van het tweede niveau“ voorzien',
	'barre_intertitre' => 'Omzetten naar {{{tussentitel}}}',
	'barre_italic' => '{cursief} zetten',
	'barre_lien' => 'Omzetten naar [hypertekst verwijzing->http://...]',
	'barre_lien_input' => 'Geef hier het adres van de koppeling op. Je kan naar een webpagina verwijzen in de vorm http://www.mijnsite.com ofwel het nummer van een artikel op deze site invullen.',
	'barre_note' => 'Omzetten naar een [[Voetnoot]]',
	'barre_paragraphe' => 'Een paragraaf toevoegen',
	'barre_quote' => '<quote>een bericht citeren</quote>',
	'bouton_changer' => 'Wijzigen',
	'bouton_chercher' => 'Zoeken',
	'bouton_choisir' => 'Selecteren',
	'bouton_deplacer' => 'Verplaatsen',
	'bouton_download' => 'Download',
	'bouton_enregistrer' => 'Opslaan',
	'bouton_radio_desactiver_messagerie_interne' => 'Intern berichtensysteem uitschakelen',
	'bouton_radio_envoi_annonces' => 'Versturen van editoriale aankondigingen',
	'bouton_radio_non_envoi_annonces' => 'Geen aankondigingen versturen',
	'bouton_radio_non_envoi_liste_nouveautes' => 'De lijst met nieuwe bijdragen niet versturen',
	'bouton_recharger_page' => 'pagina vernieuwen',
	'bouton_telecharger' => 'Downloaden',
	'bouton_upload' => 'Uploaden',
	'bouton_valider' => 'Goedkeuren',

	// C
	'cal_apresmidi' => 'namiddag',
	'cal_jour_entier' => 'hele dag',
	'cal_matin' => 'voormiddag',
	'cal_par_jour' => 'kalender per dag',
	'cal_par_mois' => 'kalender per maand',
	'cal_par_semaine' => 'kalender per week',
	'choix_couleur_interface' => 'kleur',
	'choix_interface' => 'keuze van de interface',
	'colonne' => 'Kolom',
	'confirm_changer_statut' => 'Opgelet. Je hebt gevraagd de status van dit element te wijzigen. Wil je verder gaan?',
	'correcte' => 'juist',

	// D
	'date_aujourdhui' => 'vandaag',
	'date_avant_jc' => 'v.C.',
	'date_dans' => 'in @delai@',
	'date_de_mois_1' => '@j@ januari',
	'date_de_mois_10' => '@j@ oktober',
	'date_de_mois_11' => '@j@ november',
	'date_de_mois_12' => '@j@ december',
	'date_de_mois_2' => '@j@ februari',
	'date_de_mois_3' => '@j@ maart',
	'date_de_mois_4' => '@j@ april',
	'date_de_mois_5' => '@j@ mei',
	'date_de_mois_6' => '@j@ juni',
	'date_de_mois_7' => '@j@ juli',
	'date_de_mois_8' => '@j@ augustus',
	'date_de_mois_9' => '@j@ september',
	'date_demain' => 'morgen',
	'date_fmt_heures_minutes' => '@h@:@m@uur',
	'date_fmt_heures_minutes_court' => '@h@:@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ om @heure@',
	'date_fmt_jour_heure_debut_fin' => 'op @jour@ vanaf @heure_debut@ tot @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => 'op @dtstart@@jour@ vanaf @heure_debut@@dtabbr@ tot @dtstart@@heure_fin@@dtend@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@nomjour@ @date@',
	'date_fmt_periode' => 'Van @date_debut@ tot @date_fin@',
	'date_fmt_periode_abbr' => 'Van @dtart@@date_debut@@dtabbr@ tot @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Van',
	'date_fmt_periode_to' => 'tot',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'uren',
	'date_hier' => 'gisteren',
	'date_il_y_a' => '@delai@ geleden',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'zondag',
	'date_jour_1_abbr' => 'zon.',
	'date_jour_1_initiale' => 'z.',
	'date_jour_2' => 'maandag',
	'date_jour_2_abbr' => 'maa.',
	'date_jour_2_initiale' => 'm.',
	'date_jour_3' => 'dinsdag',
	'date_jour_3_abbr' => 'din.',
	'date_jour_3_initiale' => 'di',
	'date_jour_4' => 'woensdag',
	'date_jour_4_abbr' => 'woe.',
	'date_jour_4_initiale' => 'w.',
	'date_jour_5' => 'donderdag',
	'date_jour_5_abbr' => 'don.',
	'date_jour_5_initiale' => 'do',
	'date_jour_6' => 'vrijdag',
	'date_jour_6_abbr' => 'vrij.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'zaterdag',
	'date_jour_7_abbr' => 'zat.',
	'date_jour_7_initiale' => 'z.',
	'date_jours' => 'dagen',
	'date_minutes' => 'minuten',
	'date_mois' => 'maanden',
	'date_mois_1' => 'januari',
	'date_mois_10' => 'oktober',
	'date_mois_10_abbr' => 'okt.',
	'date_mois_11' => 'november',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'december',
	'date_mois_12_abbr' => 'dec.',
	'date_mois_1_abbr' => 'jan.',
	'date_mois_2' => 'februari',
	'date_mois_2_abbr' => 'febr.',
	'date_mois_3' => 'maart',
	'date_mois_3_abbr' => 'mrt.',
	'date_mois_4' => 'april',
	'date_mois_4_abbr' => 'apr.',
	'date_mois_5' => 'mei',
	'date_mois_5_abbr' => 'mei',
	'date_mois_6' => 'juni',
	'date_mois_6_abbr' => 'juni',
	'date_mois_7' => 'juli',
	'date_mois_7_abbr' => 'juli',
	'date_mois_8' => 'augustus',
	'date_mois_8_abbr' => 'aug.',
	'date_mois_9' => 'september',
	'date_mois_9_abbr' => 'sept.',
	'date_saison_1' => 'winter',
	'date_saison_2' => 'lente',
	'date_saison_3' => 'zomer',
	'date_saison_4' => 'herfst',
	'date_secondes' => 'seconden',
	'date_semaines' => 'weken',
	'date_un_mois' => 'maand',
	'date_une_heure' => 'uur',
	'date_une_minute' => 'minuut',
	'date_une_seconde' => 'seconde',
	'date_une_semaine' => 'week',
	'dirs_commencer' => 'alvorens de installatie te beginnen',
	'dirs_preliminaire' => 'Vooraf: <b>Toegangsrechten regelen</b>',
	'dirs_probleme_droits' => 'Probleem met toegangsrechten',
	'dirs_repertoires_absents' => '<p><b>De volgende mappen werden niet gevonden:</b></p><ul>@bad_dirs@.</ul>
  <p>Waarschijnlijk is dit te wijten aan het door elkaar halen van hoofd- en kleine letters.
  Kijk na of kleine en hoofdletters van deze mappen overeenstemmen met wat hieronder getoond wordt;
 is dit niet het geval, hernoem dan de mappen met je FTP-programma om de fout zo te herstellen.</p>
  <p>Wanneer deze bewerking uitgevoerd is, kan je',
	'dirs_repertoires_suivants' => '<p><b>Je hebt geen schrijfrechten voor de volgende mappen:</b></p> <ul>@bad_dirs@.</ul>
  <p>Om dit te wijzigen, log je in met een FTP programma en wijzig je de toegangsrechten van elk van de genoemde mappen
 De procedure is gedetailleerd uitgelegd in de installatiehandleiding.</p>
  <p>Wanneer deze wijziging is doorgevoerd, kan je ',
	'double_occurrence' => 'Dubbele vermelding van @balise@',

	// E
	'en_cours' => 'bezig',
	'envoi_via_le_site' => 'Verzending via de site',
	'erreur' => 'Fout',
	'erreur_balise_non_fermee' => 'laatste haakje niet opnieuw gesloten:',
	'erreur_technique_ajaxform' => 'Ooops. Door een onvoorziene fout kan het formulier niet worden getoond. Probeer het opnieuw.',
	'erreur_technique_enregistrement_champs' => 'Een technische fout verhinderde een correcte registratie van het veld @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Een technische fout verhinderde de registratie.',
	'erreur_texte' => 'fout(en)',
	'etape' => 'Etappe',

	// F
	'fichier_introuvable' => 'Bestand @fichier@ onvindbaar', # MODIF
	'form_auteur_confirmation' => 'Gelieve je e-mail adres te bevestigen',
	'form_auteur_email_modifie' => 'Je e-mail adres is veranderd',
	'form_auteur_envoi_mail_confirmation' => 'Een bevestigingsmail werd verstuurd naar @email@. Klik op de URL in de e-mail om je e-mailadres te bevestigen.',
	'form_auteur_mail_confirmation' => 'Hallo,

Je vroeg je e-mailadres te veranderen.
Om je nieuwe adres te bevestigen, dien je op onderstaande link te klikken
(anders zal je aanvraag vervallen):

    @url@
',
	'form_deja_inscrit' => 'Je bent al ingeschreven.',
	'form_email_non_valide' => 'Je e-mailadres is niet geldig.',
	'form_forum_access_refuse' => 'Je hebt geen toegang meer tot deze website.',
	'form_forum_bonjour' => 'Hallo @nom@,',
	'form_forum_confirmer_email' => 'Klik op de volgende link om je e-mailadres te bevestigen: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Dit e-mailadres is al geregistreerd. Je kan inloggen met je gebruikelijke wachtwoord.',
	'form_forum_identifiant_mail' => 'Je nieuwe logingegevens werden je zonet via e-mail toegestuurd.',
	'form_forum_identifiants' => 'Persoonlijke inloggegevens',
	'form_forum_indiquer_nom_email' => 'Vul hier je naam en e-mailadres in. Je persoonlijke login zal je meteen per e-mail toegestuurd worden.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(Dit is een automatisch verzonden bericht)',
	'form_forum_pass' => 'wachtwoord:',
	'form_forum_probleme_mail' => 'Probleem met e-mail: de logingegevens konden niet worden verstuurd.',
	'form_forum_voici1' => 'Dit zijn je nieuwe logingegevens om een bijdrage te kunnen leveren aan de website
 "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Hierbij je logingegevens om artikelen voor te kunnen stellen op
de website "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Vul hier je e-mailadres in.',
	'form_indiquer_nom' => 'Vul hier je naam in.',
	'form_indiquer_nom_site' => 'Geef de naam van je site op.',
	'form_pet_deja_enregistre' => 'Deze website is al geregistreerd',
	'form_pet_signature_pasprise' => 'Met je naam wordt geen rekening gehouden.',
	'form_prop_confirmer_envoi' => 'Bevestig de verzending',
	'form_prop_description' => 'Beschrijving / commentaar',
	'form_prop_enregistre' => 'Je voorstel is geregistreerd. Het zal online verschijnen nadat de beheerder van de website het heeft goedgekeurd.', # MODIF
	'form_prop_envoyer' => 'Een bericht verzenden',
	'form_prop_indiquer_email' => 'Geef een geldig e-mailadres op',
	'form_prop_indiquer_nom_site' => 'Vul de naam van de website in',
	'form_prop_indiquer_sujet' => 'Vul een onderwerp in',
	'form_prop_message_envoye' => 'Bericht verzonden',
	'form_prop_non_enregistre' => 'Je voorstel is niet geregistreerd',
	'form_prop_sujet' => 'Onderwerp',
	'form_prop_url_site' => 'URL van de site',
	'format_date_incorrecte' => 'De datum of het formaat is incorrect',
	'format_heure_incorrecte' => 'De tijd of het formaat is incorrect',
	'forum_non_inscrit' => 'Je bent niet ingeschreven, ofwel is je adres of wachtwoord niet correct.',
	'forum_par_auteur' => 'door @auteur@',
	'forum_titre_erreur' => 'Fout ...',

	// I
	'ical_texte_rss_articles' => 'Het «backend» bestand van de artikelen bevindt zich op dit adres:',
	'ical_texte_rss_articles2' => 'Je kan eveneens de «backend» bestanden aanvragen voor de artikelen van iedere rubriek van deze site:',
	'ical_texte_rss_breves' => 'Daarnaast bestaat ook een bestand met de nieuwsflitsen van de site. Door het nummer van de rubriek op te geven, ontvang je automatisch de berichten van deze rubriek.',
	'icone_a_suivre' => 'Taken',
	'icone_admin_site' => 'Beheer van de site',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Help',
	'icone_articles' => 'Artikelen',
	'icone_auteurs' => 'Auteurs',
	'icone_brouteur' => 'Snelle navigatie',
	'icone_configuration_site' => 'Configuratie',
	'icone_configurer_site' => 'Je website configureren',
	'icone_creer_nouvel_auteur' => 'Een nieuwe auteur aanmaken',
	'icone_creer_rubrique' => 'Een rubriek aanmaken',
	'icone_creer_sous_rubrique' => 'Een subrubriek aanmaken',
	'icone_deconnecter' => 'Afmelden',
	'icone_discussions' => 'Discussies',
	'icone_doc_rubrique' => 'Bijlagen van de rubrieken',
	'icone_ecrire_article' => 'Een nieuw artikel schrijven',
	'icone_edition_site' => 'Redactie',
	'icone_gestion_langues' => 'Talenbeheer',
	'icone_informations_personnelles' => 'Persoonlijke gegevens',
	'icone_interface_complet' => 'Volledige interface',
	'icone_interface_simple' => 'Eenvoudige interface',
	'icone_maintenance_site' => 'Onderhoud van de website',
	'icone_messagerie_personnelle' => 'Persoonlijk berichtensysteem',
	'icone_repartition_debut' => 'De verdeling sinds het begin tonen',
	'icone_rubriques' => 'Rubrieken',
	'icone_sauver_site' => 'Maken van een reservekopie',
	'icone_site_entier' => 'Volledige site',
	'icone_sites_references' => 'Gekoppelde sites',
	'icone_statistiques' => 'Statistieken van de site',
	'icone_suivi_activite' => 'De activiteit van de site opvolgen',
	'icone_suivi_actualite' => 'Evolutie van de site',
	'icone_suivi_pettions' => 'Petities opvolgen/beheren',
	'icone_suivi_revisions' => 'Wijzigingen van de artikelen',
	'icone_supprimer_document' => 'Deze bijlage wissen',
	'icone_supprimer_image' => 'Deze afbeelding wissen',
	'icone_tous_articles' => 'Al je artikelen',
	'icone_tous_auteur' => 'Alle auteurs',
	'icone_tous_visiteur' => 'Alle bezoekers',
	'icone_visiter_site' => 'Bekijk publieke site',
	'icone_voir_en_ligne' => 'Online bekijken',
	'img_indisponible' => 'geen afbeelding beschikbaar',
	'impossible' => 'onmogelijk',
	'info_a_suivre' => 'TAKEN»',
	'info_acces_interdit' => 'Geen toegang',
	'info_acces_refuse' => 'Toegang geweigerd',
	'info_action' => 'Actie: @action@',
	'info_administrer_rubriques' => 'Je kunt deze rubriek en haar subrubrieken beheren',
	'info_adresse_non_indiquee' => 'Je hebt geen adres opgegeven om te testen!',
	'info_aide' => 'HULP:',
	'info_ajouter_mot' => 'Dit trefwoord toevoegen',
	'info_annonce' => 'AANKONDIGING',
	'info_annonces_generales' => 'Algemene aankondigingen:',
	'info_article_propose' => 'Voorgesteld artikel ',
	'info_article_publie' => 'Gepubliceerd artikel',
	'info_article_redaction' => 'Artikel in redactie',
	'info_article_refuse' => 'Artikel geweigerd',
	'info_article_supprime' => 'Artikel verwijderd',
	'info_articles' => 'Artikelen',
	'info_articles_a_valider' => 'Artikelen ter goedkeuring',
	'info_articles_nb' => '@nb@ artikelen',
	'info_articles_proposes' => 'Voorgestelde artikelen',
	'info_articles_un' => '1 artikel',
	'info_auteurs_nombre' => 'auteur(s):',
	'info_authentification_ftp' => 'Authenticatie (via FTP).',
	'info_breves_2' => 'nieuwsflitsen',
	'info_breves_nb' => '@nb@ nieuwsflitsen',
	'info_breves_un' => '1 nieuwsflits',
	'info_connexion_refusee' => 'Verbinding geweigerd',
	'info_contact_developpeur' => 'Gelieve een ontwikkelaar te contacteren.', # MODIF
	'info_contenance' => 'Deze site bevat:',
	'info_contribution' => 'bijdragen',
	'info_copyright' => '@spip@ is vrije software @lien_gpl@ distributie.',
	'info_copyright_doc' => 'Voor meer informatie, bezoek <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'onder GPL licentie',
	'info_cours_edition' => 'In voorbereiding', # MODIF
	'info_creer_repertoire' => 'Maak een bestand of map aan met de volgende naam:',
	'info_creer_repertoire_2' => 'in de submap <b>@repertoire@</b>, vervolgens:',
	'info_creer_vignette' => 'automatische aanmaak miniatuur-afbeeldingen',
	'info_creerdansrubrique_non_autorise' => 'Je hebt onvoldoende rechten om nieuwe inhoud in deze rubriek te plaatsen.',
	'info_deplier' => 'Openvouwen',
	'info_descriptif_nombre' => 'beschrijving(en):',
	'info_description' => 'Beschrijving:',
	'info_description_2' => 'Beschrijving:',
	'info_dimension' => 'Afmetingen:',
	'info_documents_nb' => '@nb@ documenten',
	'info_documents_un' => '1 document',
	'info_ecire_message_prive' => 'Een privé-bericht schrijven',
	'info_email_invalide' => 'Ongeldig e-mailadres.',
	'info_en_cours_validation' => 'Je artikelen in redactie',
	'info_en_ligne' => 'Momenteel online:',
	'info_envoyer_message_prive' => 'Een privé-bericht sturen naar deze auteur',
	'info_erreur_requete' => 'Fout bij uitvoering van de opdracht:',
	'info_erreur_squelette2' => 'Geen enkel skelet <b>@fichier@</b> is beschikbaar...',
	'info_erreur_systeme' => 'Systeemfout (error @errsys@)',
	'info_erreur_systeme2' => 'Misschien is de harde schijf vol of de database beschadigd.<br />
<span style="color:red;">Probeer <a href=\'@script@\'>de database te herstellen</a>, of neem contact op met je provider.</span>',
	'info_fini' => 'Het is klaar!',
	'info_format_image' => 'Beeldformaten die gebruikt kunnen worden om vignettes (miniatuurafbeeldingen) aan te maken: @gd_formats@.',
	'info_format_non_defini' => 'Ongedefinieerd formaat',
	'info_grand_ecran' => 'Groot scherm',
	'info_image_aide' => 'HULP',
	'info_image_process_titre' => 'Methode voor aanmaak van miniatuurafbeeldingen',
	'info_impossible_lire_page' => '<b>Fout!</b> Kan de pagina <tt><html>@test_proxy@</html></tt> niet lezen via de proxy',
	'info_installation_systeme_publication' => 'Installatie van het publicatiesysteem...',
	'info_installer_documents' => 'Je kan alle documenten in de map @upload@ automatisch toevoegen.',
	'info_installer_ftp' => 'Een beheerder kan (via FTP) bestanden in de map @upload@ bewaren en ze vervolgens hier meteen selecteren.', # MODIF
	'info_installer_images' => 'Afbeelden kunnen toegevoegd worden in JPG, GIF en PNG formaat.',
	'info_installer_images_dossier' => 'Afbeeldingen bewaren in de map @upload@ om ze hier te selecteren.',
	'info_interface_complete' => 'Volledige interface',
	'info_interface_simple' => 'Vereenvoudigde interface',
	'info_joindre_document_article' => 'Aan dit artikel kan je een bijlage toevoegen van het type',
	'info_joindre_document_rubrique' => 'In deze rubriek kan je bijlagen toevoegen van het type',
	'info_joindre_documents_article' => 'Bij je artikel kan je bijlagen voegen van het type:',
	'info_l_article' => 'het artikel',
	'info_la_breve' => 'de nieuwsflits',
	'info_la_rubrique' => 'de rubriek',
	'info_langue_principale' => 'Hoofdtaal van de site',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'door @les_auteurs@',
	'info_logo_format_interdit' => 'Alleen logo’s van het formaat @formats@ zijn toegestaan.',
	'info_logo_max_poids' => 'Logo’s mogen maximaal @maxi@ zijn (dit bestand is @actuel@).',
	'info_mail_fournisseur' => 'jullie@provider.com',
	'info_message_2' => 'BERICHT',
	'info_message_supprime' => 'VERWIJDERD BERICHT',
	'info_messages_nb' => '@nb@ berichten',
	'info_messages_un' => '1 boodschap',
	'info_mise_en_ligne' => 'Datum van online publicatie:',
	'info_modification_parametres_securite' => 'wijzigingen van de veiligheidsinstellingen',
	'info_mois_courant' => 'Gedurende deze maand:',
	'info_mot_cle_ajoute' => 'Het volgende trefwoord is toegevoegd aan ',
	'info_multi_herit' => 'Standaardtaal',
	'info_multi_langues_soulignees' => 'In de <u>onderstreepte talen</u> zijn de teksten van de interface gedeeltelijk of volledig vertaald. Als je een van deze talen kiest, worden heel wat gegevens (data, formulieren) van de publieke site automatisch vertaald. Voor de niet-onderstreepte talen zullen deze gegevens in de hoofdtaal van de site verschijnen.',
	'info_multilinguisme' => 'Meertaligheid',
	'info_nom_non_utilisateurs_connectes' => 'Je naam komt niet in de lijst van de redacteuren die online zijn.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Je naam komt in de lijst van de redacteuren die online zijn.', # MODIF
	'info_nombre_en_ligne' => 'Momenteel online:',
	'info_non_resultat' => 'Geen enkel resultaat voor "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Je gebruikt het interne berichtensysteem van deze site niet.',
	'info_nouveau_message' => 'JE HEBT EEN NIEUW BERICHT',
	'info_nouveaux_messages' => 'JE HEBT @total_messages@ NIEUWE BERICHTEN',
	'info_numero_abbreviation' => 'Nr ',
	'info_obligatoire' => 'Deze informatie is verplicht',
	'info_pense_bete' => 'MEMO',
	'info_petit_ecran' => 'Klein scherm',
	'info_petition_close' => 'Gesloten petitie',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Meerdere trefwoorden gevonden voor "@cherche_mot@":',
	'info_portfolio_automatique' => 'Automatische portfolio:',
	'info_premier_resultat' => '[@debut_limit@ eerste resultaten van de @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ eerste resultaten van de @total@]',
	'info_propose_1' => '[@nom_site_spip@] voorgesteld: @titre@',
	'info_propose_2' => 'Voorgesteld artikel

-------------------',
	'info_propose_3' => 'Het artikel "@titre@" werd voorgesteld voor publicatie',
	'info_propose_4' => 'Je wordt gevraagd het te bekijken en je mening te geven',
	'info_propose_5' => 'in het daaraan verbonden forum. Het is bereikbaar op het adres:',
	'info_publie_01' => 'Het artikel "@titre@" werd goedgekeurd door @connect_nom@.',
	'info_publie_1' => 'GEPUBLICEERD OP [@nom_site_spip@]: @titre@',
	'info_publie_2' => 'Gepubliceerd artikel
--------------------',
	'info_rechercher' => 'Zoeken',
	'info_rechercher_02' => 'Zoeken:',
	'info_remplacer_vignette' => 'Vervang de standaard mini-afbeelding door een gepersonaliseerd logo:',
	'info_rubriques_nb' => '@nb@ rubrieken',
	'info_rubriques_un' => '1 rubriek',
	'info_sans_titre_2' => 'zonder titel',
	'info_selectionner_fichier' => 'Je kan een bestand selecteren uit de map @upload@',
	'info_selectionner_fichier_2' => 'Een bestand selecteren:',
	'info_sites_nb' => '@nb@ websites',
	'info_sites_un' => '1 website',
	'info_supprimer_vignette' => 'De mini-afbeelding verwijderen',
	'info_symbole_bleu' => 'Het <b>blauwe</b> symbool wijst op een <b>memo</b>: dat wil zeggen een bericht voor persoonlijk gebruik.',
	'info_symbole_jaune' => 'Het <b>gele</b> symbool wijst op een <b>aankondiging voor alle redacteurs</b>: te wijzigen door alle beheerders en zichtbaar voor alle redacteurs.', # MODIF
	'info_symbole_vert' => 'Het <b>groene</b> symbool wijst op <b>uitgewisselde berichten met andere gebruikers</b> van deze site.', # MODIF
	'info_telecharger_nouveau_logo' => 'Een nieuw logo opladen:',
	'info_telecharger_ordinateur' => 'Opladen vanaf je computer:',
	'info_tous_resultats_enregistres' => '[alle resultaten zijn opgenomen]',
	'info_tout_afficher' => 'Alles tonen',
	'info_travaux_texte' => 'Deze site is nog niet geconfigureerd. Kom later nog eens terug...',
	'info_travaux_titre' => 'Site in opbouw',
	'info_trop_resultat' => 'Teveel resultaten voor "@cherche_mot@"; gelieve de zoekopdracht te verfijnen.',
	'info_utilisation_messagerie_interne' => 'Je gebruikt het intern berichtensysteem van de site.',
	'info_valider_lien' => 'deze link goedkeuren',
	'info_verifier_image' => ' , gelieve na te gaan of je afbeeldingen correct zijn overgezet.',
	'info_vignette_defaut' => 'standaardafbeelding',
	'info_vignette_personnalisee' => 'gepersonaliseerde afbeelding',
	'info_visite' => 'bezoek:',
	'info_vos_rendez_vous' => 'Je komende afspraken',
	'infos_vos_pense_bete' => 'Je herinneringen',

	// L
	'label_ajout_id_rapide' => 'Snelle toevoeging',
	'label_poids_fichier' => 'Afmeting',
	'lien_afficher_icones_seuls' => 'Toon alleen icoontjes',
	'lien_afficher_texte_icones' => 'Toon icoontjes en tekst',
	'lien_afficher_texte_seul' => 'Toon alleen tekst',
	'lien_liberer' => 'vrijgeven',
	'lien_liberer_tous' => 'Alles vrijgeven',
	'lien_nouvea_pense_bete' => 'NIEUWE MEMO',
	'lien_nouveau_message' => 'NIEUW BERICHT',
	'lien_nouvelle_annonce' => 'NIEUWE AANKONDIGING',
	'lien_petitions' => 'PETITIE',
	'lien_popularite' => 'populariteit: @popularite@%',
	'lien_racine_site' => 'BEGIN VAN DE SITE',
	'lien_reessayer' => 'opnieuw proberen',
	'lien_repondre_message' => 'Beantwoord dit bericht',
	'lien_supprimer' => 'verwijderen',
	'lien_tout_afficher' => 'Toon alles',
	'lien_visite_site' => 'deze site bezoeken',
	'lien_visites' => '@visites@ bezoeken',
	'lien_voir_auteur' => 'Deze auteur bekijken',
	'ligne' => 'Lijn',
	'login' => 'Verbinding',
	'login_acces_prive' => 'Toegang tot het privé gedeelte',
	'login_autre_identifiant' => 'Verbinden met een andere inlognaam',
	'login_cookie_accepte' => 'Stel je browser zo in dat ze cookies aanvaardt (tenminste voor deze site).',
	'login_cookie_oblige' => 'Om jezelf veilig aan te melden, dien je cookies te aanvaarden.',
	'login_deconnexion_ok' => 'Verbinding verbroken.',
	'login_erreur_pass' => 'Foutief wachtwoord.',
	'login_espace_prive' => 'privé gedeelte',
	'login_identifiant_inconnu' => 'Loginnaam « @login@ » is niet bekend.',
	'login_login' => 'Login:',
	'login_login2' => 'Login of e-mail adres:',
	'login_login_pass_incorrect' => '(Foutieve loginnaam of wachtwoord.)',
	'login_motpasseoublie' => 'wachtwoord vergeten?',
	'login_non_securise' => 'Opgepast, dit formulier is niet beveiligd.

   Als je wil dat derden je wachtwoord niet kunnen onderscheppen
   op het net, activeer dan Javascript 
   in je browser en',
	'login_nouvelle_tentative' => 'Nieuwe poging',
	'login_par_ici' => 'Je bent registreerd ... zo ...',
	'login_pass2' => 'Wachtwoord:',
	'login_preferez_refuser' => '<b>Als je verkiest om cookies te blokkeren</b>, is een andere (minder veilige) methode voor verbinding mogelijk:',
	'login_recharger' => 'Pagina vernieuwen',
	'login_rester_identifie' => 'Enkele dagen aangemeld blijven', # MODIF
	'login_retour_public' => 'Terug naar de publieke site',
	'login_retour_site' => 'Terug naar de publieke site',
	'login_retoursitepublic' => 'terug naar de publieke site',
	'login_sans_cookie' => 'Aanmelden zonder cookie',
	'login_securise' => 'Secure Login',
	'login_sinscrire' => 'Registreren', # MODIF
	'login_test_navigateur' => 'testen van browser/opnieuw verbinden',
	'login_verifiez_navigateur' => '(Controleer toch of je browser je wachtwoord niet heeft onthouden...)',

	// M
	'masquer_colonne' => 'Deze kolom verbergen',
	'masquer_trad' => 'vertalingen verbergen',
	'message_nouveaux_identifiants_echec' => 'Er kunnen geen nieuwe identificaties worden aanmaken.',
	'message_nouveaux_identifiants_echec_envoi' => 'De nieuwe identificaties konden niet worden verstuurd.',
	'message_nouveaux_identifiants_ok' => 'De nieuwe identificaties werden verstuurd naar @email@.',
	'module_fichiers_langues' => 'Taalbestanden',

	// N
	'navigateur_pas_redirige' => 'Wanneer je niet wordt doorverwezen, klik dan hier om verder te gaan.',
	'numero' => 'Nummer',

	// O
	'occurence' => 'Toeval',
	'onglet_affacer_base' => 'Database verwijderen',
	'onglet_auteur' => 'Auteur',
	'onglet_contenu_site' => 'Inhoud van de site',
	'onglet_evolution_visite_mod' => 'Evolutie',
	'onglet_fonctions_avances' => 'Geavanceerde functies',
	'onglet_informations_personnelles' => 'Persoonlijke informatie',
	'onglet_interactivite' => 'Interactiviteit',
	'onglet_messagerie' => 'Berichtensysteem',
	'onglet_repartition_rubrique' => 'Verdeling per rubriek',
	'onglet_save_restaur_base' => 'Backup/terugzetten van de database',
	'onglet_vider_cache' => 'Cache leegmaken',

	// P
	'pass_choix_pass' => 'Kies je nieuwe wachtwoord:',
	'pass_erreur' => 'Fout',
	'pass_erreur_acces_refuse' => '<b>Fout:</b> je hebt geen toegang meer tot deze site.',
	'pass_erreur_code_inconnu' => '<b>Fout:</b> deze code komt niet overeen met die van een bezoeker met toegangsrechten tot deze site.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Fout:</b> het adres <tt>@email_oubli@</tt> is niet geregistreerd op deze site.',
	'pass_erreur_non_valide' => '<b>Fout:</b> het e-mailadres <tt>@email_oubli@</tt> is niet geldig!',
	'pass_erreur_probleme_technique' => '<b>Fout:</b> de e-mail kon niet worden verzonden wegens een technisch probleem.',
	'pass_espace_prive_bla' => 'Het privé gedeelte van deze site is alleen
toegankelijk voor bezoekers na registratie. Eenmaal geregistreerd,
kan je artikelen ter redactie inzien, zelf artikelen toevoegen en deelnemen aan de forums.', # MODIF
	'pass_forum_bla' => 'Je hebt gevraagd om deel te nemen aan een forum dat gereserveerd is voor geregistreerde gebruikers.', # MODIF
	'pass_indiquez_cidessous' => 'Vul hieronder het e-mailadres in waarmee je je eerder hebt geregistreerd. Je
zult een e-mail ontvangen met uitleg over hoe je opnieuw toegang kan krijgen tot de site.',
	'pass_mail_passcookie' => '(dit is een automatisch gegenereerd bericht)
Om opnieuw toegang te krijgen tot de site
@nom_site_spip@ (@adresse_site@)

Ga naar het volgende adres:

    @sendcookie@

Je kan er een nieuw wachtwoord invoeren en 
opnieuw verbinding maken met de site

', # MODIF
	'pass_mot_oublie' => 'Wachtwoord vergeten?',
	'pass_nouveau_enregistre' => 'Je nieuwe wachtwoord is genoteerd.',
	'pass_nouveau_pass' => 'Nieuw wachtwoord',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Wachtwoord vergeten',
	'pass_procedure_changer' => 'Om je wachtwoord te wijzigen, moeten we eerst je identiteit controleren. Geef hiervoor het e-mailadres dat is gekoppeld aan je account.',
	'pass_quitter_fenetre' => 'Venster sluiten',
	'pass_rappel_login' => 'Herinnering: je aanmeldingsnaam (login) is "@login@".',
	'pass_recevoir_mail' => 'Je zult een e-mail ontvangen (wanneer je e-mailadres geldig is) met daarin een link om je wachtwoord opnieuw in te stellen.',
	'pass_retour_public' => 'Terug naar de publiek site',
	'pass_rien_a_faire_ici' => 'Niets te zoeken hier.',
	'pass_vousinscrire' => 'Je inschrijven op de site',
	'precedent' => 'vorige',
	'previsualisation' => 'Schermweergave',
	'previsualiser' => 'Vooraf tonen',

	// R
	'retour' => 'Terugkeren',

	// S
	'spip_conforme_dtd' => 'SPIP beschouwt dit document als conform met zijn DOCTYPE:',
	'squelette' => 'skelet',
	'squelette_inclus_ligne' => 'skelet inbegrepen, lijn',
	'squelette_ligne' => 'skelet, lijn',
	'stats_visites_et_popularite' => '@visites@ bezoeken; populariteit: @popularite@',
	'suivant' => 'volgende',

	// T
	'taille_go' => '@taille@ GB',
	'taille_ko' => '@taille@ kB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ bytes',
	'taille_octets_bi' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Wanneer je vertrouwd bent met de interface, kan je klikken op «',
	'texte_actualite_site_2' => 'volledige interface',
	'texte_actualite_site_3' => '» om meer mogelijkheden te openen.',
	'texte_creation_automatique_vignette' => 'Op deze site is de automatische aanmaak van miniaturen (vignettes) geactiveerd. Als je via dit formulier afbeeldingen oplaadt van het formaat @gd_formats@, zullen miniaturen aangemaakt worden met een maximale grootte van  @taille_preview@ pixels.',
	'texte_documents_associes' => 'De volgende documenten zijn bij het artikel gevoegd, maar zijn niet rechtstreeks in de tekst opgenomen.
    Naargelang de opmaak van de publieke website zullen ze als bijlage verschijnen.',
	'texte_erreur_mise_niveau_base' => 'Databasefout bij het updaten.
 De afbeelding <b>@fichier@</b> werd niet opgeladen (artikel @id_article@).
 Noteer deze referentie en probeer nogmaals het opladen van de afbeelding. Kijk vervolgens na of de afbeeldingen correct verschijnen in het artikel.',
	'texte_erreur_visiteur' => 'Je probeerde toegang te krijgen tot het privé-gedeelte met een login die hiervoor geen rechten heeft.',
	'texte_inc_auth_1' => 'Je bent aangemeld als
  <b>@auth_login@</b>, maar deze naam komt niet (meer) voor in de database. 
  Probeer je',
	'texte_inc_auth_2' => 'opnieuw aan te melden',
	'texte_inc_auth_3' => ', nadat je je browser eventueel gesloten en opnieuw herstart hebt.',
	'texte_inc_config' => 'De wijzigingen die op deze pagina worden aangebracht,
 beïnvloeden grondig de werking van de volledige website. We raden
 je aan hier niets aan te wijzigen tot je voldoende bekend
 bent met het functioneren van het SPIP systeem.
 <br /><br /><b>Laat het beheer van deze pagina over aan de webmaster van de site.</b>',
	'texte_inc_meta_1' => 'Het systeem merkt een fout bij het wegschrijven van het bestand <code>@fichier@</code>. Gelieve, als beheerder van de site,', # MODIF
	'texte_inc_meta_2' => 'de schrijfrechten na te kijken',
	'texte_inc_meta_3' => 'op de map <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'in redactie',
	'texte_statut_poubelle' => 'in de vuilnisbak',
	'texte_statut_propose_evaluation' => 'ter evaluatie',
	'texte_statut_publie' => 'online geplaatst',
	'texte_statut_refuse' => 'geweigerd',
	'titre_ajouter_mot_cle' => 'TREFWOORD TOEVOEGEN:',
	'titre_cadre_raccourcis' => 'SNELKOPPELINGEN:',
	'titre_changer_couleur_interface' => 'Kleur van de interface wijzigen',
	'titre_image_admin_article' => 'Je kan dit artikel beheren',
	'titre_image_administrateur' => 'Beheerder', # MODIF
	'titre_image_aide' => 'Help over dit onderwerp',
	'titre_image_auteur_supprime' => 'Auteur gewist',
	'titre_image_redacteur' => 'Redacteur zonder toegang',
	'titre_image_redacteur_02' => 'Redacteur',
	'titre_image_selecteur' => 'Toon de lijst',
	'titre_image_visiteur' => 'Bezoeker',
	'titre_joindre_document' => 'DOCUMENT TOEVOEGEN',
	'titre_mots_cles' => 'TREFWOORDEN',
	'titre_probleme_technique' => 'Opgelet: een technisch probleem (SQL server) verhindert de toegang tot dit deel van de site. Dank voor je begrip.',
	'titre_publier_document' => 'EEN DOCUMENT PUBLICEREN IN DEZE RUBRIEK',
	'titre_signatures_attente' => 'Ondertekeningen wachtend op validatie',
	'titre_signatures_confirmees' => 'Bevestigde ondertekeningen',
	'titre_statistiques' => 'Statistieken van de site',
	'titre_titre_document' => 'Titel van het document:',
	'todo' => 'binnenkort beschikbaar',
	'trad_definir_reference' => 'Kies "@titre@" als referentie voor vertalingen',
	'trad_reference' => '(verwijzing naar vertalingen)',

	// U
	'upload_limit' => 'Dit bestand is te groot voor de server; de maximaal toegelaten grootte in <i>upload</i> is @max@.',

	// Z
	'zbug_balise_b_aval' => ': beginnende opmaakcode B',
	'zbug_balise_inexistante' => 'Slecht gedeclareerd baken @balise@ voor @from@',
	'zbug_balise_sans_argument' => 'Argument niet inbegrepen in het baken @balise@',
	'zbug_boucle' => 'lus',
	'zbug_boucle_recursive_undef' => 'Niet bepaalde recursieve lus: @nom@',
	'zbug_calcul' => 'berekening',
	'zbug_champ_hors_boucle' => 'Veld @champ@ buiten de lus',
	'zbug_champ_hors_motif' => 'Veld @champ@ buiten een context @motif@',
	'zbug_code' => 'code',
	'zbug_critere_inconnu' => 'Onbekend criterium @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} op een tabel zonder automische primaire sleutel',
	'zbug_distant_interdit' => 'Extern verboden',
	'zbug_doublon_table_sans_cle_primaire' => 'Doublon op een tabel zonder primaire sleutel',
	'zbug_doublon_table_sans_index' => '"Doublon" op een tabel zonder index',
	'zbug_erreur_boucle_double' => 'Dubbele definitie van de @id@ lus',
	'zbug_erreur_boucle_fermant' => 'Lus @id@ niet gesloten ',
	'zbug_erreur_boucle_syntaxe' => 'Incorrecte syntax van de lus @id@',
	'zbug_erreur_compilation' => 'Compilatiefout',
	'zbug_erreur_execution_page' => 'Uitvoeringsfout',
	'zbug_erreur_filtre' => 'Filter @filtre@ niet bepaald ',
	'zbug_erreur_meme_parent' => 'Het criterium {meme_parent} is uitsluitend van toepassing op de lussen (FORUMS) en (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Fout(en) in het skelet',
	'zbug_hors_compilation' => 'Buiten Compilatie',
	'zbug_info_erreur_squelette' => 'Fout op de site',
	'zbug_inversion_ordre_inexistant' => 'Omzetting van niet-bestaande aard',
	'zbug_pagination_sans_critere' => 'Baken #PAGINATION zonder criterium {pagination} of toegepast in een recursieve lus',
	'zbug_parametres_inclus_incorrects' => 'Incorrecte parameter: @param@',
	'zbug_profile' => 'Berekeningstijd: @time@',
	'zbug_resultat' => 'resultaat',
	'zbug_serveur_indefini' => 'SQL server niet gedefinieerd',
	'zbug_statistiques' => 'Statistieken van de SQL verzoeken, gerangschikt volgens tijdsduur',
	'zbug_table_inconnue' => 'SQL tabel « @table@ » onbekend',
	'zxml_connus_attributs' => 'onbekende eigenschappen',
	'zxml_de' => 'van',
	'zxml_inconnu_attribut' => 'onbekende eigenschap',
	'zxml_inconnu_balise' => 'onbekend baken',
	'zxml_inconnu_entite' => 'onbekende entiteit',
	'zxml_inconnu_id' => 'onbekende ID',
	'zxml_mais_de' => 'maar van',
	'zxml_non_conforme' => 'is niet in overeenstemming met',
	'zxml_non_fils' => 'is geen zoon van ',
	'zxml_nonvide_balise' => 'niet leeg baken',
	'zxml_obligatoire_attribut' => 'verplichte eigenschap, maar afwezig in',
	'zxml_succession_fils_incorrecte' => 'incorrecte opeenvolging van de zonen',
	'zxml_survoler' => 'beweeg hierover voor de correcties',
	'zxml_valeur_attribut' => 'waarde van de eigenschap',
	'zxml_vide_balise' => 'leeg baken',
	'zxml_vu' => 'eerder gezien',
];
